Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DeviceNameToDevicePath ¶
Types ¶
type ExportDetails ¶
type MDADM ¶
type MDADM struct {
MDADM commandrunner.CommandRunner
}
func NewMDADM ¶
func NewMDADM( runner *commandrunner.MDADM, ) *MDADM
func (*MDADM) LogicalVolume ¶
func (m *MDADM) LogicalVolume( metadata *logicalvolume.Metadata, ) (*logicalvolume.LogicalVolume, error)
LogicalVolume returns a logical volume by its metadata.
func (*MDADM) LogicalVolumes ¶
func (m *MDADM) LogicalVolumes( _ *raidcontroller.Metadata, ) ([]*logicalvolume.LogicalVolume, error)
LogicalVolumes returns all the logical volumes on the system.
type MDADMDevices ¶
type MDADMExportDetails ¶
type MDADMExportDetails struct {
RaidLevel logicalvolume.RAIDLevel // MD_LEVEL
DevicesCount int // MD_DEVICES
Metadata string // MD_METADATA
UUID string // MD_UUID
Name string // MD_NAME
ArraySize string // MD_ARRAY_SIZE
DeviceName string // MD_DEVNAME
Devices map[string]MDADMDevices // MD_DEV_0, MD_DEV_1, ...
}
func ParseMDADMExportOutput ¶
func ParseMDADMExportOutput(output []byte) ([]*MDADMExportDetails, error)
type SSACLI ¶
type SSACLI struct {
SSACLI commandrunner.CommandRunner
LSBLK commandrunner.CommandRunner
}
func NewSSACLI ¶
func NewSSACLI( ssacli *commandrunner.SSACLI, lsblk *commandrunner.LSBLK, ) *SSACLI
func (*SSACLI) LogicalVolume ¶
func (s *SSACLI) LogicalVolume(metadata *logicalvolume.Metadata) ( *logicalvolume.LogicalVolume, error, )
LogicalVolume returns a logical volume for a given metadata.
func (*SSACLI) LogicalVolumes ¶
func (s *SSACLI) LogicalVolumes(metadata *raidcontroller.Metadata) ( []*logicalvolume.LogicalVolume, error, )
LogicalVolumes returns all logical volumes for a given controller.
Click to show internal directories.
Click to hide internal directories.